Re:Show HN: 10-40% faster LZMA decoder using x86 CMOVcc
by injinj on Monday December 13, 2021 @04:23PM
(#29544844)
Decent speedup on my 3970x. Including this patch reduced the number of instructions in lzma_decoder.s (using gcc 8.3.1) by about 8% (4417 lines of asm vs 4824). With perf stat, an astonishing branches-missed reduction from 409K to 104K.
Using the firefox example from the gist:
The xz shipped from the system: The xz patched.